## Summary

## data

This package exports included records to a csv file for structured data extraction.

To compare csv version across the Git history, we recommend tools like [daff](https://github.com/paulfitz/daff).

<!-- ## Links -->
